# orm2pydantic

Convert SQLAlchemy models to Pydantic models

## Usage

...

## Installation

`pip install orm2pydantic`

## Dependencies

Python Version ..., OS ...

## Building from source

Run `python -m build`
